@@ -8,8 +8,10 @@ use uv_redacted::DisplaySafeUrl;
 pub enum ServiceParseError {
     #[error(transparent)]
     InvalidUrl(#[from] url::ParseError),
-    #[error("only HTTPS (or HTTP on localhost) is supported")]
-    UnsupportedScheme,
+    #[error("Unsupported scheme: {0}")]
+    UnsupportedScheme(String),
+    #[error("HTTPS is required for non-local hosts")]
+    HttpsRequired,
 }
 
 /// A service URL that wraps [`DisplaySafeUrl`] for CLI usage.
@@ -36,9 +38,8 @@ impl Service {
         match url.scheme() {
             "https" => Ok(()),
             "http" if matches!(url.host_str(), Some("localhost" | "127.0.0.1")) => Ok(()),
-            #[cfg(test)]
-            "http" => Ok(()),
-            _ => Err(ServiceParseError::UnsupportedScheme),
+            "http" => Err(ServiceParseError::HttpsRequired),
+            value => Err(ServiceParseError::UnsupportedScheme(value.to_string())),
         }
     }
 }
