@@ -11,8 +11,8 @@ use owo_colors::OwoColorize;
 use rustc_hash::{FxHashMap, FxHashSet};
 use tracing::{debug, warn};
 
-use uv_configuration::PreviewMode;
 use uv_fs::Simplified;
+use uv_preview::Preview;
 use uv_python::downloads::PythonDownloadRequest;
 use uv_python::managed::{
     ManagedPythonInstallations, PythonMinorVersionLink, python_executable_dir,
@@ -30,7 +30,7 @@ pub(crate) async fn uninstall(
     targets: Vec<String>,
     all: bool,
     printer: Printer,
-    preview: PreviewMode,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let installations = ManagedPythonInstallations::from_settings(install_dir)?.init()?;
 
@@ -66,7 +66,7 @@ async fn do_uninstall(
     targets: Vec<String>,
     all: bool,
     printer: Printer,
-    preview: PreviewMode,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let start = std::time::Instant::now();
 
@@ -112,13 +112,11 @@ async fn do_uninstall(
         }
         if !found {
             // Clear any remnants in the registry
-            if preview.is_enabled() {
-                #[cfg(windows)]
-                {
-                    uv_python::windows_registry::remove_orphan_registry_entries(
-                        &installed_installations,
-                    );
-                }
+            #[cfg(windows)]
+            {
+                uv_python::windows_registry::remove_orphan_registry_entries(
+                    &installed_installations,
+                );
             }
 
             if matches!(requests.as_slice(), [PythonRequest::Default]) {
