@@ -1,7 +1,7 @@
 use crate::common::{TestContext, uv_snapshot, venv_bin_path};
 use anyhow::Result;
 use assert_cmd::assert::OutputAssertExt;
-use assert_fs::fixture::{FileWriteStr, PathChild, PathCreateDir};
+use assert_fs::fixture::{FileTouch, FileWriteStr, PathChild, PathCreateDir};
 use flate2::bufread::GzDecoder;
 use fs_err::File;
 use indoc::{formatdoc, indoc};
@@ -50,13 +50,9 @@ fn built_by_uv_direct_wheel() -> Result<()> {
         .assert()
         .success();
 
-    uv_snapshot!(context
-        .run()
-        .arg("python")
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg(BUILT_BY_UV_TEST_SCRIPT)
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r###"
+        .arg(BUILT_BY_UV_TEST_SCRIPT), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -138,13 +134,9 @@ fn built_by_uv_direct() -> Result<()> {
 
     drop(wheel_dir);
 
-    uv_snapshot!(context
-        .run()
-        .arg("python")
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg(BUILT_BY_UV_TEST_SCRIPT)
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r###"
+        .arg(BUILT_BY_UV_TEST_SCRIPT), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -169,7 +161,8 @@ fn built_by_uv_editable() -> Result<()> {
 
     // Without the editable, pytest fails.
     context.pip_install().arg("pytest").assert().success();
-    Command::new(context.interpreter())
+    context
+        .python_command()
         .arg("-m")
         .arg("pytest")
         .current_dir(built_by_uv)
@@ -200,7 +193,7 @@ fn built_by_uv_editable() -> Result<()> {
     drop(wheel_dir);
 
     // Now, pytest passes.
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-m")
         .arg("pytest")
         // Avoid showing absolute paths and column dependent layout
@@ -229,9 +222,7 @@ fn preserve_executable_bit() -> Result<()> {
     let project_dir = context.temp_dir.path().join("preserve_executable_bit");
     context
         .init()
-        .arg("--build-backend")
-        .arg("uv")
-        .arg("--preview")
+        .arg("--lib")
         .arg(&project_dir)
         .assert()
         .success();
@@ -304,7 +295,7 @@ fn rename_module() -> Result<()> {
         module-name = "bar"
 
         [build-system]
-        requires = ["uv_build>=0.5,<0.8"]
+        requires = ["uv_build>=0.7,<10000"]
         build-backend = "uv_build"
     "#})?;
 
@@ -323,8 +314,7 @@ fn rename_module() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-wheel")
-        .arg(temp_dir.path())
-        .env("UV_PREVIEW", "1"), @r###"
+        .arg(temp_dir.path()), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -340,11 +330,9 @@ fn rename_module() -> Result<()> {
         .success();
 
     // Importing the module with the `module-name` name succeeds.
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import bar")
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r###"
+        .arg("import bar"), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -354,11 +342,9 @@ fn rename_module() -> Result<()> {
     "###);
 
     // Importing the package name fails, it was overridden by `module-name`.
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import foo")
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r###"
+        .arg("import foo"), @r###"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -390,7 +376,7 @@ fn rename_module_editable_build() -> Result<()> {
         module-name = "bar"
 
         [build-system]
-        requires = ["uv_build>=0.5,<0.8"]
+        requires = ["uv_build>=0.7,<10000"]
         build-backend = "uv_build"
     "#})?;
 
@@ -402,8 +388,7 @@ fn rename_module_editable_build() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-editable")
-        .arg(temp_dir.path())
-        .env("UV_PREVIEW", "1"), @r###"
+        .arg(temp_dir.path()), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -419,11 +404,9 @@ fn rename_module_editable_build() -> Result<()> {
         .success();
 
     // Importing the module with the `module-name` name succeeds.
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import bar")
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r###"
+        .arg("import bar"), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -452,7 +435,7 @@ fn build_module_name_normalization() -> Result<()> {
         version = "1.0.0"
 
         [build-system]
-        requires = ["uv_build>=0.5,<0.8"]
+        requires = ["uv_build>=0.7,<10000"]
         build-backend = "uv_build"
 
         [tool.uv.build-backend]
@@ -470,7 +453,7 @@ fn build_module_name_normalization() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: Expected a Python module at: `src/Django_plugin/__init__.py`
+    error: Expected a Python module at: src/Django_plugin/__init__.py
     ");
 
     fs_err::create_dir_all(context.temp_dir.join("src/Django_plugin"))?;
@@ -484,7 +467,7 @@ fn build_module_name_normalization() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: Expected a Python module at: `src/Django_plugin/__init__.py`
+    error: Expected a Python module at: src/Django_plugin/__init__.py
     ");
 
     // Use `Django_plugin` instead of `django_plugin`
@@ -514,11 +497,9 @@ fn build_module_name_normalization() -> Result<()> {
         .assert()
         .success();
 
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
-        .arg("import Django_plugin")
-        // Python on windows
-        .env(EnvVars::PYTHONUTF8, "1"), @r"
+        .arg("import Django_plugin"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -566,7 +547,7 @@ fn build_sdist_with_long_path() -> Result<()> {
         version = "1.0.0"
 
         [build-system]
-        requires = ["uv_build>=0.7,<0.8"]
+        requires = ["uv_build>=0.7,<10000"]
         build-backend = "uv_build"
     "#})?;
     context
@@ -583,8 +564,7 @@ fn build_sdist_with_long_path() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path())
-        .env("UV_PREVIEW", "1"), @r###"
+        .arg(temp_dir.path()), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -610,21 +590,20 @@ fn sdist_error_without_module() -> Result<()> {
         version = "1.0.0"
 
         [build-system]
-        requires = ["uv_build>=0.7,<0.8"]
+        requires = ["uv_build>=0.7,<10000"]
         build-backend = "uv_build"
     "#})?;
 
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path())
-        .env("UV_PREVIEW", "1"), @r"
+        .arg(temp_dir.path()), @r"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
-    error: Expected a Python module at: `src/foo/__init__.py`
+    error: Expected a Python module at: src/foo/__init__.py
     ");
 
     fs_err::create_dir(context.temp_dir.join("src"))?;
@@ -632,14 +611,13 @@ fn sdist_error_without_module() -> Result<()> {
     uv_snapshot!(context
         .build_backend()
         .arg("build-sdist")
-        .arg(temp_dir.path())
-        .env("UV_PREVIEW", "1"), @r"
+        .arg(temp_dir.path()), @r"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
-    error: Expected a Python module at: `src/foo/__init__.py`
+    error: Expected a Python module at: src/foo/__init__.py
     ");
 
     Ok(())
@@ -682,7 +660,7 @@ fn complex_namespace_packages() -> Result<()> {
             module-name = "{project_name_dist_info}.{part_name}"
 
             [build-system]
-            requires = ["uv_build>=0.5.15,<10000"]
+            requires = ["uv_build>=0.7,<10000"]
             build-backend = "uv_build"
             "#
         };
@@ -697,7 +675,6 @@ fn complex_namespace_packages() -> Result<()> {
 
         context
             .build()
-            .arg("--preview")
             .arg(project.path())
             .arg("--out-dir")
             .arg(dist.path())
@@ -728,7 +705,7 @@ fn complex_namespace_packages() -> Result<()> {
     "
     );
 
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
         .arg("from complex_project.part_b import two; print(two())"),
         @r"
@@ -746,7 +723,6 @@ fn complex_namespace_packages() -> Result<()> {
         context.filters(),
         context
             .pip_install()
-            .arg("--preview")
             .arg("-e")
             .arg("complex-project-part_a")
             .arg("-e")
@@ -769,7 +745,7 @@ fn complex_namespace_packages() -> Result<()> {
     "
     );
 
-    uv_snapshot!(Command::new(context.interpreter())
+    uv_snapshot!(context.python_command()
         .arg("-c")
         .arg("from complex_project.part_b import two; print(two())"),
         @r"
@@ -783,3 +759,273 @@ fn complex_namespace_packages() -> Result<()> {
     );
     Ok(())
 }
+
+/// Test that a symlinked file (here: license) gets included.
+#[test]
+#[cfg(unix)]
+fn symlinked_file() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let project = context.temp_dir.child("project");
+    context
+        .init()
+        .arg("--lib")
+        .arg(project.path())
+        .assert()
+        .success();
+
+    project.child("pyproject.toml").write_str(indoc! {r#"
+        [project]
+        name = "project"
+        version = "1.0.0"
+        license-files = ["LICENSE"]
+
+        [build-system]
+        requires = ["uv_build>=0.7,<10000"]
+        build-backend = "uv_build"
+        "#
+    })?;
+
+    let license_file = context.temp_dir.child("LICENSE");
+    let license_symlink = project.child("LICENSE");
+
+    let license_text = "Project license";
+    license_file.write_str(license_text)?;
+    fs_err::os::unix::fs::symlink(license_file.path(), license_symlink.path())?;
+
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-sdist")
+        .arg(context.temp_dir.path())
+        .current_dir(project.path()), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    project-1.0.0.tar.gz
+
+    ----- stderr -----
+    ");
+
+    uv_snapshot!(context
+        .build_backend()
+        .arg("build-wheel")
+        .arg(context.temp_dir.path())
+        .current_dir(project.path()), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    project-1.0.0-py3-none-any.whl
+
+    ----- stderr -----
+    ");
+
+    uv_snapshot!(context.filters(), context.pip_install().arg("project-1.0.0-py3-none-any.whl"), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 1 package in [TIME]
+    Prepared 1 package in [TIME]
+    Installed 1 package in [TIME]
+     + project==1.0.0 (from file://[TEMP_DIR]/project-1.0.0-py3-none-any.whl)
+    ");
+
+    // Check that we included the actual license text and not a broken symlink.
+    let installed_license = context
+        .site_packages()
+        .join("project-1.0.0.dist-info")
+        .join("licenses")
+        .join("LICENSE");
+    assert!(
+        fs_err::symlink_metadata(&installed_license)?
+            .file_type()
+            .is_file()
+    );
+    let license = fs_err::read_to_string(&installed_license)?;
+    assert_eq!(license, license_text);
+
+    Ok(())
+}
+
+/// Ignore invalid build backend settings when not building.
+///
+/// They may be from another `uv_build` version that has a different schema.
+#[test]
+fn invalid_build_backend_settings_are_ignored() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! {r#"
+        [project]
+        name = "built-by-uv"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+
+        [tool.uv.build-backend]
+        # Error: `source-include` must be a list
+        source-include = "data/build-script.py"
+
+        [build-system]
+        requires = ["uv_build>=10000,<10001"]
+        build-backend = "uv_build"
+    "#})?;
+
+    // Since we are not building, this must pass without complaining about the error in
+    // `tool.uv.build-backend`.
+    uv_snapshot!(context.filters(), context.lock(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 1 package in [TIME]
+    ");
+
+    Ok(())
+}
+
+/// Error when there is a relative module root outside the project root, such as
+/// `tool.uv.build-backend.module-root = ".."`.
+#[test]
+fn error_on_relative_module_root_outside_project_root() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! {r#"
+        [project]
+        name = "project"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+
+        [tool.uv.build-backend]
+        module-root = ".."
+
+        [build-system]
+        requires = ["uv_build>=0.7,<10000"]
+        build-backend = "uv_build"
+    "#})?;
+
+    context.temp_dir.child("__init__.py").touch()?;
+
+    uv_snapshot!(context.filters(), context.build(), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building source distribution (uv build backend)...
+      × Failed to build `[TEMP_DIR]/`
+      ╰─▶ Module root must be inside the project: ..
+    ");
+
+    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building wheel (uv build backend)...
+      × Failed to build `[TEMP_DIR]/`
+      ╰─▶ Module root must be inside the project: ..
+    ");
+
+    Ok(())
+}
+
+/// Error when there is a relative data directory outside the project root, such as
+/// `tool.uv.build-backend.data.headers = "../headers"`.
+#[test]
+fn error_on_relative_data_dir_outside_project_root() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let project = context.temp_dir.child("project");
+    project.create_dir_all()?;
+
+    let pyproject_toml = project.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! {r#"
+        [project]
+        name = "project"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+
+        [tool.uv.build-backend.data]
+        headers = "../header"
+
+        [build-system]
+        requires = ["uv_build>=0.7,<10000"]
+        build-backend = "uv_build"
+    "#})?;
+
+    let project_module = project.child("src/project");
+    project_module.create_dir_all()?;
+    project_module.child("__init__.py").touch()?;
+
+    context.temp_dir.child("headers").create_dir_all()?;
+
+    uv_snapshot!(context.filters(), context.build().arg("project"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building source distribution (uv build backend)...
+      × Failed to build `[TEMP_DIR]/project`
+      ╰─▶ The path for the data directory headers must be inside the project: ../header
+    ");
+
+    uv_snapshot!(context.filters(), context.build().arg("project").arg("--wheel"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building wheel (uv build backend)...
+      × Failed to build `[TEMP_DIR]/project`
+      ╰─▶ The path for the data directory headers must be inside the project: ../header
+    ");
+
+    Ok(())
+}
+
+/// Show an explicit error when there is a venv in source tree.
+#[test]
+fn venv_in_source_tree() {
+    let context = TestContext::new("3.12");
+
+    context
+        .init()
+        .arg("--lib")
+        .arg("--name")
+        .arg("foo")
+        .assert()
+        .success();
+
+    context
+        .venv()
+        .arg(context.temp_dir.join("src").join("foo").join(".venv"))
+        .assert()
+        .success();
+
+    uv_snapshot!(context.filters(), context.build(), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building source distribution (uv build backend)...
+      × Failed to build `[TEMP_DIR]/`
+      ╰─▶ Virtual environments must not be added to source distributions or wheels, remove the directory or exclude it from the build: src/foo/.venv
+    ");
+
+    uv_snapshot!(context.filters(), context.build().arg("--wheel"), @r"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Building wheel (uv build backend)...
+      × Failed to build `[TEMP_DIR]/`
+      ╰─▶ Virtual environments must not be added to source distributions or wheels, remove the directory or exclude it from the build: src/foo/.venv
+    ");
+}
